#
# spec file for package commoncpp2
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           commoncpp2
%define lname	libcommoncpp2-1_8-0
Version:        1.8.1
Release:        15.1
Summary:        A GNU lirbary package for creating portable C++ programs
License:        GPL-2.0+
Group:          Development/Libraries/C and C++
Url:            https://www.gnu.org/software/commoncpp/

Source:         https://ftp.gnu.org/gnu/commoncpp/%name-%version.tar.gz
Source1:        https://ftp.gnu.org/gnu/commoncpp/%name-%version.tar.gz.sig
Source2:        %name.keyring
Patch1:         commoncpp2-overflow.patch
Patch2:         commoncpp2-applog.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  zlib-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Common C++ is a GNU package which offers portable "abstraction" of
system services such as threads, networks, and sockets.  Common C++
also offers individual frameworks generally useful to developing
portable C++ applications including a object persistance engine, math
libraries, threading, sockets, etc.  Common C++ is small, and highly
portable. Common C++ will support most Unix operating systems as well
as Win32, in addition to GNU/Linux.

%package -n %lname
Summary:        A GNU library package for creating portable C++ programs
Group:          System/Libraries
# Added for 13.1
Obsoletes:      commoncpp2 < %version-%release
Provides:       commoncpp2 = %version-%release

%description -n %lname
Common C++ is a GNU package which offers portable "abstraction" of
system services such as threads, networks, and sockets.  Common C++
also offers individual frameworks generally useful to developing
portable C++ applications including a object persistance engine, math
libraries, threading, sockets, etc.

%package devel
Summary:        Files for developing CommonC++ applications
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
Requires:       libstdc++-devel
Requires:       zlib-devel
Provides:       CommonC++-devel = %version
Provides:       commonc++-devel < %version
Obsoletes:      CommonC++-devel = %version
Obsoletes:      commonc++-devel < %version

%description devel
This package contains include files, static libraries and some
documentation for the CommonC++ package. It is needed for developing
and compiling CommonC++ applications.

%package doc
Summary:        Documentation for GNU commoncpp
Group:          Documentation/HTML
Requires:       %name = %version
Provides:       CommonC++-doc = %version
Obsoletes:      CommonC++-doc < %version

%description doc
Common C++ is a GNU package which offers portable "abstraction" of
system services such as threads, networks, and sockets.  Common C++
also offers individual frameworks generally useful to developing
portable C++ applications including a object persistance engine, math
libraries, threading, sockets, etc.  Common C++ is small, and highly
portable. Common C++ will support most Unix operating systems as well
as Win32, in addition to GNU/Linux.

%prep
%setup -q
%patch -P 1 -P 2 -p1

%build
autoreconf -fiv
%configure --enable-shared --disable-static --with-pic
# Do not include build date in documentation
echo "HTML_TIMESTAMP = NO" >> doc/Doxyfile
# Practice has shown it does not always fly.
make -j1

%install
b="%buildroot"
mkdir -p "$b/%_mandir/man3"
make DESTDIR="$b" install %{?_smp_mflags}
install -d "$b/%_defaultdocdir/%name/html"
install -m 644 doc/html/* "$b/%_defaultdocdir/%name/html/"
install -m 644 AUTHORS COPYING COPYING.addendum NEWS README TODO ChangeLog "$b/%_defaultdocdir/%name/"
rm -f "$b/%_infodir/commoncpp2.info"*
find "$b" -type f -name "*.la" -delete -print
%fdupes %buildroot/%_prefix

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%defattr(-,root,root)
%_libdir/libcc*-1.8.so.0*

%files devel
%defattr(-,root,root)
%_includedir/cc++
%_datadir/aclocal/ost_check2.m4
%_libdir/libcc*.so
%_bindir/ccgnu2-config
%_libdir/pkgconfig/*.pc

%files doc
%defattr(-,root,root)
%doc %_defaultdocdir/%name/

%changelog
* Thu Aug 13 2015 mpluskal@suse.com
- Specfile cleaning only: Use original source URL, add GPG
  signature, explicit autotools build dependencies,
  removal of Obsolete/Provides for source package,
  avoid inclusion of timestamps in documentation.
* Thu Jun 13 2013 jengelh@inai.de
- Implement shlib packaging guidelines
* Thu Sep  6 2012 s.canepa@pentaengineering.it
- Updated to upstream version 1.8.1
- Deleted all no more needed patches
- Applied patch based on trunk commit of applog.cpp
* Mon May 21 2012 idonmez@suse.com
- Fix wrong memset call in inaddr.cpp
* Thu Feb 23 2012 kkeil@linux-pingi.de
- Disable parallel builds again, it fails randomly (depending
  how many parallel jobs are started)
* Sat Feb 11 2012 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Enable parallel build, it seems to work.
* Fri Sep 30 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Tue Apr  5 2011 crrodriguez@opensuse.org
-Fix memset-with-zero-length in thread.cpp
* Sat Apr 24 2010 coolo@novell.com
- buildrequire pkg-config to fix provides
* Fri Feb  5 2010 jengelh@medozas.de
- compile fix for mempager.cpp
* Mon Jun  8 2009 ro@suse.de
- strchr now returns a const char*
* Sun May 11 2008 crrodriguez@suse.de
- Correct dependency chain between commoncpp2->ccrtp->libzrtpcpp
- disable static libraries
* Mon Apr 14 2008 schwab@suse.de
- Work around misuse of libtool.
* Mon Jan 14 2008 rhafer@suse.de
- update to 1.6.1
  - some fixups for mingw32 based builds
  - patch for ThreadQueue from Angelo Naselli
  - patch for LinkedDouble from Sergio Repetto (changed abi)
- fixed buildfailures on 64bit Plattforms
* Thu Jan 10 2008 ro@suse.de
- remove make -j for now, makefile deps are broken
* Tue Nov 27 2007 rhafer@suse.de
- update to 1.5.9 (smaller changes in the build enviroment)
- fixed rpmlint warnings
- Updated library's SONAME as the ABI was changed with the 1.5.3
  release. (Bug #343847, see also Debian Bug# 402009)
* Fri Aug  3 2007 dmueller@suse.de
- update to 1.5.7
  * downstream gcc 4.3 and isRunning fix from Mark Purcell
  * sha digest cleanup
  * visibility for shared library symbols
  * hi resolution and monotonic timers for TimerPort
  * TimerPort synchronized sleep
  * Angelo Naselli's revised timed buffer thread queue
  * other minor patches and fixes, code cleanup
* Sat Apr 28 2007 dmueller@suse.de
- fix undefined references in libccext2
* Tue Jan 16 2007 rhafer@suse.de
- update to 1.5.3
  * some code cleanup of operators and const members
  * fix for include path passed in .pc files.
  * added IPV4/V6Cidr objects for use in routing policies.
  * removed libxml2 wrapper option so we can better focus on Common
    C++'s built-in sax parser.
  * addition of "clean" MemPager protected member, used by Keydata
    to assure dynamic object behavior is correct and non-leaking.
  * fix for getThread id if priv is NULL.
  * fix for extern "C" of handlers and types.
  * fix for keydata loadPrefix for w32.
  * use readData/writeData for overflow/underflow in TCPStream to
    allow override in SSLStream
  * optional introduction of SSLStream class
  * new SSLStream class cannot be built substituting gnutls yet
    because openssl emulation is not thread-safe and so class must
    be rewritten explicitly for gnutls.  Hence for now ssl is
    disabled by default
- Use RPM_OPT_FLAGS for CXXFLAGS
* Fri Nov 10 2006 ro@suse.de
- fix docu permissions
* Tue Jul 18 2006 kkaempf@suse.de
- update to 1.4.2
  Most notable changes since 1.3.1:
  - include path rename from /usr/include/cc++2
    to /usr/include/cc++
  - RefPointer and RefObject classes for reference count managed
    objects
  - LinkedSingle and LinkedDouble self managing linked list classes
  - MapTable and mapObject classes for managed hash indexes
  - Some convenience functions for keydata
  - conditional build for extras library
  - isRealtime check for thread priority management
  - moved templates into main header
  - keydata uses bigger default paging for >32 bit pointers.
  - new errLockFailure indicator for Thread shared files.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Apr  7 2005 kkaempf@suse.de
- update to 1.3.1
- add virtual destructors to classes with virtual functions (will
  keep gcc4 happy)
* Fri Jan 21 2005 rhafer@suse.de
- updated to 1.3.0
* Tue Aug 10 2004 kkaempf@suse.de
- undef __DLLRTL since its used in windows only and triggers lots
  of warnings in linux.
* Fri Aug  6 2004 rhafer@suse.de
- updated to 1.2.4
* Sat Jan 10 2004 adrian@suse.de
- let -devel package also require libstdc++-devel
- fix build as user
* Mon Jul 28 2003 rhafer@suse.de
- updated to 1.0.13
- use prebuilt documentation to drop "doxygen" from neededforbuild
* Wed May 14 2003 rhafer@suse.de
- updated to 1.0.9
- remove uneeded files from BuildRoot
* Sat Jan  4 2003 kkaempf@suse.de
- fix assignment ambiguity.
* Thu Nov 28 2002 rhafer@suse.de
- Updated to 1.0.7
* Sun Nov  3 2002 ro@suse.de
- comment out unused function on alpha
* Thu Oct 24 2002 rhafer@suse.de
- Updated to 1.0.3
- moved html docs to /usr/share/doc/packages/CommonC++ (#20551)
- added libxml2-devel to Requires for -devel (#20552)
- small fix in Makefile.am (CommonC++-.dif)
* Thu Aug  8 2002 rhafer@suse.de
- Updated to 0.99.7
* Thu Jun  6 2002 rhafer@suse.de
- updated to version 0.99.4
- included libxml2 in neededforbuild to build with XML support
- new subpackage -doc which contains HTML documentation
* Thu Apr 25 2002 sf@suse.de
- added %%{_libdir} to configure to compile on lib64-archs
* Mon Apr 22 2002 ro@suse.de
- update to commoncpp2-0.99.3
- package should probably be renamed
* Thu Apr 11 2002 coolo@suse.de
- patch for gcc 3.1
* Tue Apr  2 2002 ro@suse.de
- fixed for automake/autoconf
* Thu Feb 21 2002 schwab@suse.de
- Fix configure check for <exception> header.
* Mon Feb 11 2002 rhafer@suse.de
- updated to 1.9.5
- Cleanup in .spec (removed calls to ldconfig and strip)
* Fri Jan 11 2002 schwab@suse.de
- Fix missing namespace prefix.
* Thu Jan 10 2002 rhafer@suse.de
- Update to version 1.9.4
* Thu Jan  3 2002 schwab@suse.de
- Provide atomic operations for ia64.
* Thu Dec 13 2001 kkaempf@suse.de
- update to 1.9.2
* Wed Dec  5 2001 kkaempf@suse.de
- Update to version 1.9.1
- Rename to CommonC++ (as specified in original .spec file)
- Clean up .spec file, adapt filelist to original .spec file
* Tue Oct 16 2001 kkaempf@suse.de
- Update to version 1.6.1
* Wed Jul  4 2001 rhafer@suse.de
- Updated to version 1.5.0
- some changes for gcc3.0
* Wed Jun  6 2001 rhafer@suse.de
- Updated to version 1.4.3
- workaround for problem with pthread_delay_np()
* Wed May  9 2001 mfabian@suse.de
- bzip2 sources
* Thu Apr 19 2001 rhafer@suse.de
- Updated to version 1.4.1
* Thu Mar 29 2001 schwab@suse.de
- Don't include kernel headers.
- Fix use of %%suse_update_config.
- Move *.so to devel package.
* Tue Mar  6 2001 rhafer@suse.de
- renamed development package to commonc++-devel
- replaced static compiler flags with $RPM_OPT_FLAGS
* Mon Mar  5 2001 rhafer@suse.de
- initial Version
